==> apache-kylin-2.5.2-source-release.zip: apache-kylin-2.5.2/core-common/src/main/java/org/apache/kylin/common/util/SparkEntry.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *  
 *     http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kylin.common.util;

import org.apache.commons.lang.StringUtils;

/**
 */
public final class SparkEntry {

    public static void main(String[] args) throws Exception {
        System.out.println("SparkEntry args:" + StringUtils.join(args, " "));
        if (!(args.length >= 2)) {
            throw new IllegalArgumentException(String.valueOf("-className is required"));
        }
        if (!(args[0].equals("-className"))) {
            throw new IllegalArgumentException(String.valueOf("-className is required"));
        }
        final String className = args[1];
        final Object o = Class.<AbstractApplication> forName(className).newInstance();
        if (!(o instanceof AbstractApplication)) {
            throw new IllegalArgumentException(String.valueOf(className + " is not a subClass of AbstractApplication"));
        }
        String[] appArgs = new String[args.length - 2];
        for (int i = 2; i < args.length; i++) {
            appArgs[i - 2] = args[i];
        }
        AbstractApplication abstractApplication = (AbstractApplication) o;
        abstractApplication.execute(appArgs);
    }
}

==> apache-kylin-3.1.3-source-release.zip: apache-kylin-3.1.3/core-common/src/main/java/org/apache/kylin/common/util/SparkEntry.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *  
 *     http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kylin.common.util;

import org.apache.commons.lang.StringUtils;

/**
 */
public final class SparkEntry {

    public static void main(String[] args) throws Exception {
        System.out.println("SparkEntry args:" + StringUtils.join(args, " "));
        if (!(args.length >= 2)) {
            throw new IllegalArgumentException(String.valueOf("-className is required"));
        }
        if (!(args[0].equals("-className"))) {
            throw new IllegalArgumentException(String.valueOf("-className is required"));
        }
        final String className = args[1];
        final Object o = Class.forName(className).newInstance();
        if (!(o instanceof AbstractApplication)) {
            throw new IllegalArgumentException(String.valueOf(className + " is not a subClass of AbstractApplication"));
        }
        String[] appArgs = new String[args.length - 2];
        for (int i = 2; i < args.length; i++) {
            appArgs[i - 2] = args[i];
        }
        AbstractApplication abstractApplication = (AbstractApplication) o;
        abstractApplication.execute(appArgs);
    }
}
